@@ -36,6 +36,13 @@
 #include <ucommon/string.h>
 #endif
 
+#define	DATE_STRING_SIZE		10
+#define	DATE_BUFFER_SIZE		11
+#define	TIME_STRING_SIZE		8
+#define	TIME_BUFFER_SIZE		9
+#define	DATETIME_STRING_SIZE	19
+#define	DATETIME_BUFFER_SIZE	20
+
 NAMESPACE_UCOMMON
 
 #ifdef __BORLANDC__
@@ -61,7 +68,7 @@ protected:
 
 	/**
 	 * A method to use to "post" any changed values when shadowing
-	 * a mixed object class.  This is used by DateNumber.
+	 * a mixed object class.  This is used by DateNumber and string classes.
 	 */
 	virtual void update(void);
 
@@ -164,6 +171,11 @@ public:
 	 */
 	long get(void) const;
 
+	/**
+	 * Set (update) the date with current date.
+	 */
+	void set(void);
+
 	/**
 	 * Set the julian date based on an ISO date string of specified size.
 	 * @param pointer to date string field.
@@ -404,6 +416,11 @@ public:
 	 */
 	char *get(char *buffer) const;
 
+	/**
+	 * Set (update) the time with current time.
+	 */
+	void set(void);
+
 	/**
 	 * Set time from a hh:mm:ss formatted string.
 	 * @param pointer to time field.
@@ -605,7 +622,7 @@ public:
 	 * @param minute of object (0-59).
 	 * @param second of object (0-59).
 	 */
-	DateTime(int year, unsigned month = 1, unsigned day = 1,
+	DateTime(int year, unsigned month, unsigned day,
 		 int hour = 0, int minute = 0, int second = 0);
 
 	/**
@@ -764,6 +781,11 @@ public:
 	inline operator long() const
 		{return Date::get();};
 
+	/**
+	 * Set (update) the date and time with current date and time.
+	 */
+	void set(void);
+
 	/**
 	 * Convert date and time to julian day number.
 	 * @return julian day number as a double.
@@ -804,6 +826,107 @@ public:
 	static void release(struct tm *object);
 };
 
+/**
+ * A DateTime string class.  This can be used to access the date and time
+ * as a standard string without requiring an external buffer.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short a datetime class that returns strings.
+ */
+class __EXPORT DateTimeString : public DateTime
+{
+public:
+	/**
+	 * Specify string buffer mode.  By default we form a string with date
+	 * and time.
+	 */
+	typedef enum {
+		DATE, TIME, BOTH} mode_t;
+	
+private:
+	char buffer[DATETIME_BUFFER_SIZE];
+	mode_t mode;
+
+protected:
+	void update(void);
+
+public:
+	/**
+	 * Construct a date and time from C libraray time_t type.		
+	 * @param string mode to use.
+	 * @param time type to make date and time from.
+	 */
+  	DateTimeString(time_t time);
+
+	/**
+	 * Construct a date and time from C library time structure.
+	 * @param tm structure from C library (from glt or gmt).
+	 */
+	DateTimeString(struct tm *tm);
+
+	/**
+	 * Construct a date and time from ISO string buffer.
+	 * @param pointer to string field holding date and time.
+	 * @param size of field if not null terminated string.
+	 */
+	DateTimeString(const char *pointer, size_t size = 0);
+
+	/**
+	 * Construct a date and time object from explicit date and time values.
+	 * @param year of object.
+	 * @param month of object (1-12).
+	 * @param day of month of object (1-31).
+	 * @param hour of object (0-23).
+	 * @param minute of object (0-59).
+	 * @param second of object (0-59).
+	 */
+	DateTimeString(int year, unsigned month, unsigned day,
+		 int hour = 0, int minute = 0, int second = 0);
+
+	/**
+	 * Create a datetime object from another object.
+	 * @param object to copy.
+	 */
+	DateTimeString(const DateTimeString& object);
+
+	/**
+	 * Construct a new date and time object with current date and time.
+	 */
+	DateTimeString(mode_t string = DateTimeString::BOTH);
+
+	/**
+	 * Destroy date time string.
+	 */
+	virtual ~DateTimeString();
+
+	/**
+	 * Extract char from string.
+	 *
+	 * @return string of datetime.
+	 */
+	inline const char *c_str(void)
+		{return buffer;};
+
+	/**
+	 * Cast to string.
+	 *
+	 * @return string of datetime.
+	 */
+	inline operator const char *(void)
+		{return buffer;};
+
+	/**
+	 * Set (update) the date and time with current date and time.
+	 */
+	void set(void);
+
+	/**
+	 * Set the string mode.
+	 * @param string mode to use.
+	 */
+	void set(mode_t string);
+};
+
 /**
  * A number class that manipulates a string buffer that is also a date.
  *
@@ -813,8 +936,7 @@ public:
 class __EXPORT DateNumber : public Number, public Date
 {
 protected:
-	void update(void)
-		{fromJulian(buffer);};
+	void update(void);
 
 public:
 	/**
@@ -827,6 +949,11 @@ public:
 	 * Release a datenumber object.
 	 */
 	virtual ~DateNumber();
+
+	/**
+	 * Set date number to current date.
+	 */
+	void set(void);
 };
 
 /**
@@ -834,6 +961,11 @@ public:
  */
 typedef	DateTime	datetime_t;
 
+/**
+ * Convenience type for using DateTimeString object.
+ */
+typedef	DateTimeString	datetimestring_t;
+
 /**
  * Convenience type for using Date object.
  */
