@@ -952,7 +952,7 @@ public:
 	 * @param end of line marker characters or NULL if not used.
 	 * @return token extracted from string or NULL if no more tokens found.
 	 */
-	static const char *token(char *text, char **last, const char *list, const char *quote = NULL, const char *end = NULL);
+	static char *token(char *text, char **last, const char *list, const char *quote = NULL, const char *end = NULL);
 
 	/**
 	 * Skip after lead characters in a null terminated string.
@@ -1222,7 +1222,7 @@ public:
 	 * @param end of line marker characters or NULL if not used.
 	 * @return token extracted from string or NULL if no more tokens found.
 	 */
-	inline static const char *token(string& object, char **last, const char *list, const char *quote = NULL, const char *end = NULL)
+	inline static char *token(string& object, char **last, const char *list, const char *quote = NULL, const char *end = NULL)
 		{return token(object.c_mem(), last, list, quote, end);};
 
 	/**
@@ -1679,6 +1679,64 @@ typedef	string string_t;
  */
 typedef string String;
 
+/**
+ * Compare two null terminated strings if equal.
+ * @param s1 string to compare.
+ * @param s2 string to compare.
+ * @return true if equal.
+ */
+inline bool eq(char const *s1, char const *s2)
+	{return String::equal(s1, s2);}
+
+/**
+ * Compare two null terminated strings if equal up to specified size.
+ * @param s1 string to compare.
+ * @param s2 string to compare.
+ * @param size of string to compare.
+ * @return true if equal.
+ */
+inline bool eq(char const *s1, char const *s2, size_t size)
+	{return String::equal(s1, s2, size);}
+
+/**
+ * Compare two string objects if equal.
+ * @param s1 string to compare.
+ * @param s2 string to compare.
+ * @return true if equal.
+ */
+inline bool eq(String &s1, String &s2)
+	{return String::equal(s1.c_str(), s2.c_str());}
+
+/**
+ * Compare two null terminated strings if equal ignoring case.  This is
+ * related to stricmp or gcc strcasecmp.
+ * @param s1 string to compare.
+ * @param s2 string to compare.
+ * @return true if equal.
+ */
+inline bool ieq(char const *s1, char const *s2)
+	{return String::case_equal(s1, s2);}
+
+/**
+ * Compare two null terminated strings if equal for a specified size 
+ * ignoring case.  This is related to stricmp or gcc strcasecmp.
+ * @param s1 string to compare.
+ * @param s2 string to compare.
+ * @param size of string to compare.
+ * @return true if equal.
+ */
+inline bool ieq(char const *s1, char const *s2, size_t size)
+	{return String::case_equal(s1, s2);}
+
+/**
+ * Compare two string objects if equal ignoring case.  This is
+ * related to stricmp or gcc strcasecmp.
+ * @param s1 string to compare.
+ * @param s2 string to compare.
+ * @return true if equal.
+ */
+inline bool ieq(String &s1, String &s2)
+	{return String::case_equal(s1.c_str(), s2.c_str());}
 
 END_NAMESPACE
 
