@@ -38,15 +38,15 @@ extern "C" int main()
 	String::fill(buff, 32, ' ');
 	stringbuf<128> mystr;
 	mystr = (string_t)"hello" + (string_t)" this is a test";
-	assert(!stricmp("hello this is a test", *mystr));
-	assert(!stricmp("second test", *testing));
-	assert(!stricmp(" is a test", mystr(-10)));
+	assert(ieq("hello this is a test", *mystr));
+	assert(ieq("second test", *testing));
+	assert(ieq(" is a test", mystr(-10)));
 	mystr = "  abc 123 \n  ";
-	assert(!stricmp("abc 123", String::strip(mystr.c_mem(), " \n")));
+	assert(ieq("abc 123", String::strip(mystr.c_mem(), " \n")));
 	String::set(buff, sizeof(buff), "this is \"a test\"");
 	while(NULL != (tp = String::token(buff, &tokens, " ", "\"\"")) && count < 4)
 		array[count++] = tp;
 	assert(count == 3);
-	assert(!stricmp(array[1], "is"));
-	assert(!stricmp(array[2], "a test"));
+	assert(ieq(array[1], "is"));
+	assert(ieq(array[2], "a test"));
 }
